<!DOCTYPE html>
<html>
  <head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <link rel="icon" type="image/png" href="../../static/images/icons/favicon-32x32.png" sizes="32x32" />
    <link rel="icon" type="image/png" href="../../static/images/icons/favicon-16x16.png" sizes="16x16" />
    <title>{{ pagetitle }}</title>
    <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/font-awesome/4.7.0/css/font-awesome.min.css">
    <link rel="stylesheet" href="../../static/css/arxivstyle.css">
  </head>
  <body>
  <header>
    <!-- contains Cornell logo and sponsor statement -->
    <div class="attribution level is-marginless">
      <div class="level-left"><a class="level-item" href="https://library.cornell.edu"><img class="logo" src="../../static/images/CUL-reduced-white-SMALL.svg" alt="Cornell University Library" /></a></div>
      <div class="level-right"><p class="sponsors level-item">We gratefully acknowledge support from<br /> the Simons Foundation and member institutions</p></div>
    </div>
    <!-- contains arXiv identity and search bar for now -->
    <div class="identity level is-marginless">
      <div class="level-left"><h1 class="level-item"><a href="https://arxiv.org">arXiv.org</a></h1></div>
      <div class="search-block level-right">
        <form class="level-item">
          <div class="field has-addons">
            <div class="control">
              <input class="input is-small" type="text" name="query" placeholder="Search..." />
              <p class="help"><a href="">Help</a> | <a href="">Advanced Search</a></p>
            </div>
            <div class="control">
              <div class="select is-small">
                <select name="searchtype">
                  <option selected="selected">All fields</option>
                  <option>Title</option>
                  <option>Author</option>
                  <option>arXiv ID</option>
                </select>
              </div>
            </div>
            <button class="button is-small is-warning">Search</button>
        </div>
        </form>
      </div>
    </div> <!-- closes identity -->
    <div class="user-tools box is-pulled-right"><a href="">Login</a> | <a href="">My Account</a> | <a href="">Logout</a></div>
  </header>
  <content>
  <section class="section">
    <div class="container">
      <div class="content">
      <h1>Search: Showing results 1 through 25 (of 177 total) for
      <a href="/find/grp_math,grp_physics/1/ti:+blast/0/1/0/all/0/1?skip=0&amp;query_id=11871357850ddd36">ti:blast</a></h1>
      <div id="dlpage">
      <a href="/find/grp_math,grp_physics/1/ti:+blast/0/1/0/all/0/1?query_id=11871357850ddd36&amp;form=yes">Back to Search form</a>
      &nbsp;|&nbsp;<a href="/find/grp_math,grp_physics/1/ti:+blast/0/1/0/all/0/1?skip=25&amp;query_id=11871357850ddd36">Next 25 results</a><p>The URL for this search is http://arxiv.org:443/find/grp_math,grp_physics/1/ti:+blast/0/1/0/all/0/1<br /></p>
      <dl>
      <dt>1.  <span class="list-identifier"><a href="/abs/1708.07991" title="Abstract">arXiv:1708.07991</a> [<a href="/pdf/1708.07991" title="Download PDF">pdf</a>, <a href="/ps/1708.07991" title="Download PostScript">ps</a>, <a href="/format/1708.07991" title="Other formats">other</a>]</span></dt>
      <dd>
      <div class="meta">
      <div class="list-title mathjax">
      <span class="descriptor">Title:</span> Expansion of a radial plasma blast shell into an ambient plasma
      </div>
      <div class="list-authors">
      <span class="descriptor">Authors:</span>
      <a href="/find/physics/1/au:+Dieckmann_M/0/1/0/all/0/1">M E Dieckmann</a>,
      <a href="/find/physics/1/au:+Doria_D/0/1/0/all/0/1">D Doria</a>,
      <a href="/find/physics/1/au:+Ahmed_H/0/1/0/all/0/1">H Ahmed</a>,
      <a href="/find/physics/1/au:+Romagnani_L/0/1/0/all/0/1">L Romagnani</a>,
      <a href="/find/physics/1/au:+Sarri_G/0/1/0/all/0/1">G Sarri</a>,
      <a href="/find/physics/1/au:+Folini_D/0/1/0/all/0/1">D Folini</a>,
      <a href="/find/physics/1/au:+Walder_R/0/1/0/all/0/1">R Walder</a>,
      <a href="/find/physics/1/au:+Bret_A/0/1/0/all/0/1">A Bret</a>,
      <a href="/find/physics/1/au:+Borghesi_M/0/1/0/all/0/1">M Borghesi</a>
      </div>
      <div class="list-comments">
      <span class="descriptor">Comments:</span> 5 pages, 4 figures, accepted by Physics of Plasmas
      </div>
      <div class="list-subjects">
      <span class="descriptor">Subjects:</span> <span class="primary-subject">Plasma Physics (physics.plasm-ph)</span>

      </div>
      </div>
      </dd>
      <dt>2.  <span class="list-identifier"><a href="/abs/1708.05405" title="Abstract">arXiv:1708.05405</a> [<a href="/pdf/1708.05405" title="Download PDF">pdf</a>, <a href="/format/1708.05405" title="Other formats">other</a>]</span></dt>
      <dd>
      <div class="meta">
      <div class="list-title mathjax">
      <span class="descriptor">Title:</span> Massive BLAST: An Architecture for Realizing Ultra-High Data Rates for  Large-Scale MIMO
      </div>
      <div class="list-authors">
      <span class="descriptor">Authors:</span>
      <a href="/find/cs/1/au:+Shental_O/0/1/0/all/0/1">Ori Shental</a>,
      <a href="/find/cs/1/au:+Venkatesan_S/0/1/0/all/0/1">Sivarama Venkatesan</a>,
      <a href="/find/cs/1/au:+Ashikhmin_A/0/1/0/all/0/1">Alexei Ashikhmin</a>,
      <a href="/find/cs/1/au:+Valenzuela_R/0/1/0/all/0/1">Reinaldo A. Valenzuela</a>
      </div>
      <div class="list-subjects">
      <span class="descriptor">Subjects:</span> <span class="primary-subject">Information Theory (cs.IT)</span>

      </div>
      </div>
      </dd>
      <dt>3.  <span class="list-identifier"><a href="/abs/1705.08336" title="Abstract">arXiv:1705.08336</a> [<a href="/pdf/1705.08336" title="Download PDF">pdf</a>]</span></dt>
      <dd>
      <div class="meta">
      <div class="list-title mathjax">
      <span class="descriptor">Title:</span> A Fluid-Structure Interaction Solver for Compressible Flows with  Applications in Blast Loading on Thin Elastic Structures
      </div>
      <div class="list-authors">
      <span class="descriptor">Authors:</span>
      <a href="/find/physics/1/au:+Bailoor_S/0/1/0/all/0/1">Shantanu Bailoor</a>,
      <a href="/find/physics/1/au:+Annangi_A/0/1/0/all/0/1">Aditya Annangi</a>,
      <a href="/find/physics/1/au:+Seo_J/0/1/0/all/0/1">Jung Hee Seo</a>,
      <a href="/find/physics/1/au:+Bhardwaj_R/0/1/0/all/0/1">Rajneesh Bhardwaj</a>
      </div>
      <div class="list-subjects">
      <span class="descriptor">Subjects:</span> <span class="primary-subject">Fluid Dynamics (physics.flu-dyn)</span>

      </div>
      </div>
      </dd>
      <dt>4.  <span class="list-identifier"><a href="/abs/1702.01735" title="Abstract">arXiv:1702.01735</a> [<a href="/pdf/1702.01735" title="Download PDF">pdf</a>, <a href="/format/1702.01735" title="Other formats">other</a>]</span></dt>
      <dd>
      <div class="meta">
      <div class="list-title mathjax">
      <span class="descriptor">Title:</span> Higher-order anisotropies in the Blast-Wave Model - disentangling flow  and density field anisotropies
      </div>
      <div class="list-authors">
      <span class="descriptor">Authors:</span>
      <a href="/find/nucl-th/1/au:+Cimerman_J/0/1/0/all/0/1">Jakub Cimerman</a>,
      <a href="/find/nucl-th/1/au:+Tomasik_B/0/1/0/all/0/1">Boris Tomasik</a>,
      <a href="/find/nucl-th/1/au:+Csanad_M/0/1/0/all/0/1">Mate Csanad</a>,
      <a href="/find/nucl-th/1/au:+Lokos_S/0/1/0/all/0/1">Sandor Lokos</a>
      </div>
      <div class="list-comments">
      <span class="descriptor">Comments:</span> 13 pages, 10 figures; This is the version accepted for publication. The main change comparing to previous version is addition of a new Section and four new figures where we illustrate the model on very simple comparison to data from top RHIC energy
      </div>
      <div class="list-journal-ref">
      <span class="descriptor">Journal-ref:</span> Eur. Phys. J. A (2017) 53: 161
      </div>
      <div class="list-subjects">
      <span class="descriptor">Subjects:</span> <span class="primary-subject">Nuclear Theory (nucl-th)</span>; High Energy Physics - Experiment (hep-ex); High Energy Physics - Phenomenology (hep-ph)

      </div>
      </div>
      </dd>
      <dt>5.  <span class="list-identifier"><a href="/abs/1612.05629" title="Abstract">arXiv:1612.05629</a> [<a href="/pdf/1612.05629" title="Download PDF">pdf</a>, <a href="/ps/1612.05629" title="Download PostScript">ps</a>, <a href="/format/1612.05629" title="Other formats">other</a>]</span></dt>
      <dd>
      <div class="meta">
      <div class="list-title mathjax">
      <span class="descriptor">Title:</span> A Blast Wave Model With Viscous Corrections
      </div>
      <div class="list-authors">
      <span class="descriptor">Authors:</span>
      <a href="/find/nucl-th/1/au:+Yang_Z/0/1/0/all/0/1">Zhidong Yang</a>,
      <a href="/find/nucl-th/1/au:+Fries_R/0/1/0/all/0/1">Rainer J. Fries</a>
      </div>
      <div class="list-comments">
      <span class="descriptor">Comments:</span> Proceedings for HQ 2016,4 pages,3 figures
      </div>
      <div class="list-subjects">
      <span class="descriptor">Subjects:</span> <span class="primary-subject">Nuclear Theory (nucl-th)</span>

      </div>
      </div>
      </dd>
      <dt>6.  <span class="list-identifier"><a href="/abs/1610.05692" title="Abstract">arXiv:1610.05692</a> [<a href="/pdf/1610.05692" title="Download PDF">pdf</a>, <a href="/ps/1610.05692" title="Download PostScript">ps</a>, <a href="/format/1610.05692" title="Other formats">other</a>]</span></dt>
      <dd>
      <div class="meta">
      <div class="list-title mathjax">
      <span class="descriptor">Title:</span> Origin of asymmetries in X-ray emission lines from the blast wave of the  2014 outburst of nova V745 Sco
      </div>
      <div class="list-authors">
      <span class="descriptor">Authors:</span>
      <a href="/find/astro-ph/1/au:+Orlando_S/0/1/0/all/0/1">S. Orlando</a>,
      <a href="/find/astro-ph/1/au:+Drake_J/0/1/0/all/0/1">J. J. Drake</a>,
      <a href="/find/astro-ph/1/au:+Miceli_M/0/1/0/all/0/1">M. Miceli</a>
      </div>
      <div class="list-comments">
      <span class="descriptor">Comments:</span> 16 pages, 17 Figures; accepted for publication on MNRAS
      </div>
      <div class="list-subjects">
      <span class="descriptor">Subjects:</span> <span class="primary-subject">High Energy Astrophysical Phenomena (astro-ph.HE)</span>

      </div>
      </div>
      </dd>
      <dt>7.  <span class="list-identifier"><a href="/abs/1608.05456" title="Abstract">arXiv:1608.05456</a> [<a href="/pdf/1608.05456" title="Download PDF">pdf</a>, <a href="/format/1608.05456" title="Other formats">other</a>]</span></dt>
      <dd>
      <div class="meta">
      <div class="list-title mathjax">
      <span class="descriptor">Title:</span> Instrumental performance and results from testing of the BLAST-TNG  receiver, submillimeter optics, and MKID arrays
      </div>
      <div class="list-authors">
      <span class="descriptor">Authors:</span>
      <a href="/find/astro-ph/1/au:+Galitzki_N/0/1/0/all/0/1">Nicholas Galitzki</a>,
      <a href="/find/astro-ph/1/au:+Ade_P/0/1/0/all/0/1">Peter Ade</a>,
      <a href="/find/astro-ph/1/au:+Angile_F/0/1/0/all/0/1">Francesco E. Angile</a>,
      <a href="/find/astro-ph/1/au:+Ashton_P/0/1/0/all/0/1">Peter Ashton</a>,
      <a href="/find/astro-ph/1/au:+Austermann_J/0/1/0/all/0/1">Jason Austermann</a>,
      <a href="/find/astro-ph/1/au:+Billings_T/0/1/0/all/0/1">Tashalee Billings</a>,
      <a href="/find/astro-ph/1/au:+Che_G/0/1/0/all/0/1">George Che</a>,
      <a href="/find/astro-ph/1/au:+Cho_H/0/1/0/all/0/1">Hsiao-Mei Cho</a>,
      <a href="/find/astro-ph/1/au:+Davis_K/0/1/0/all/0/1">Kristina Davis</a>,
      <a href="/find/astro-ph/1/au:+Devlin_M/0/1/0/all/0/1">Mark Devlin</a>,
      <a href="/find/astro-ph/1/au:+Dicker_S/0/1/0/all/0/1">Simon Dicker</a>,
      <a href="/find/astro-ph/1/au:+Dober_B/0/1/0/all/0/1">Bradley J. Dober</a>,
      <a href="/find/astro-ph/1/au:+Fissel_L/0/1/0/all/0/1">Laura M. Fissel</a>,
      <a href="/find/astro-ph/1/au:+Fukui_Y/0/1/0/all/0/1">Yasuo Fukui</a>,
      <a href="/find/astro-ph/1/au:+Gao_J/0/1/0/all/0/1">Jiansong Gao</a>,
      <a href="/find/astro-ph/1/au:+Gordon_S/0/1/0/all/0/1">Samuel Gordon</a>,
      <a href="/find/astro-ph/1/au:+Groppi_C/0/1/0/all/0/1">Christopher E. Groppi</a>,
      <a href="/find/astro-ph/1/au:+Hillbrand_S/0/1/0/all/0/1">Seth Hillbrand</a>,
      <a href="/find/astro-ph/1/au:+Hilton_G/0/1/0/all/0/1">Gene C. Hilton</a>,
      <a href="/find/astro-ph/1/au:+Hubmayr_J/0/1/0/all/0/1">Johannes Hubmayr</a>,
      <a href="/find/astro-ph/1/au:+Irwin_K/0/1/0/all/0/1">Kent D. Irwin</a>,
      <a href="/find/astro-ph/1/au:+Klein_J/0/1/0/all/0/1">Jeffrey Klein</a>,
      <a href="/find/astro-ph/1/au:+Li_D/0/1/0/all/0/1">Dale Li</a>,
      <a href="/find/astro-ph/1/au:+Li_Z/0/1/0/all/0/1">Zhi-Yun Li</a>,
      <a href="/find/astro-ph/1/au:+Lourie_N/0/1/0/all/0/1">Nathan P. Lourie</a>,
      <a href="/find/astro-ph/1/au:+Lowe_I/0/1/0/all/0/1">Ian Lowe</a>,
      <a href="/find/astro-ph/1/au:+Mani_H/0/1/0/all/0/1">Hamdi Mani</a>,
      <a href="/find/astro-ph/1/au:+Martin_P/0/1/0/all/0/1">Peter G. Martin</a>,
      <a href="/find/astro-ph/1/au:+Mauskopf_P/0/1/0/all/0/1">Philip Mauskopf</a>,
      <a href="/find/astro-ph/1/au:+McKenney_C/0/1/0/all/0/1">Christopher McKenney</a>,
      <a href="/find/astro-ph/1/au:+Nati_F/0/1/0/all/0/1">Federico Nati</a>,
      <a href="/find/astro-ph/1/au:+Novak_G/0/1/0/all/0/1">Giles Novak</a>,
      <a href="/find/astro-ph/1/au:+Pascale_E/0/1/0/all/0/1">Enzo Pascale</a>,
      <a href="/find/astro-ph/1/au:+Pisano_G/0/1/0/all/0/1">Giampaolo Pisano</a>,
      <a href="/find/astro-ph/1/au:+Santos_F/0/1/0/all/0/1">Fabio P. Santos</a>,
      <a href="/find/astro-ph/1/au:+Scott_D/0/1/0/all/0/1">Douglas Scott</a>,
      <a href="/find/astro-ph/1/au:+Sinclair_A/0/1/0/all/0/1">Adrian Sinclair</a>,
      <a href="/find/astro-ph/1/au:+Soler_J/0/1/0/all/0/1">Juan D. Soler</a>,
      <a href="/find/astro-ph/1/au:+Tucker_C/0/1/0/all/0/1">Carole Tucker</a>,
      <a href="/find/astro-ph/1/au:+Underhill_M/0/1/0/all/0/1">Matthew Underhill</a>,
      <a href="/find/astro-ph/1/au:+Vissers_M/0/1/0/all/0/1">Michael Vissers</a>,
      <a href="/find/astro-ph/1/au:+Williams_P/0/1/0/all/0/1">Paul Williams</a>
      </div>
      <div class="list-comments">
      <span class="descriptor">Comments:</span> Presented at SPIE Millimeter, Submillimeter, and Far-Infrared Detectors and Instrumentation for Astronomy VIII, June 29th, 2016
      </div>
      <div class="list-journal-ref">
      <span class="descriptor">Journal-ref:</span> Proc. SPIE 9914, Millimeter, Submillimeter, and Far-Infrared
        Detectors and Instrumentation for Astronomy VIII, 99140J (July 19, 2016)
      </div>
      <div class="list-subjects">
      <span class="descriptor">Subjects:</span> <span class="primary-subject">Instrumentation and Methods for Astrophysics (astro-ph.IM)</span>

      </div>
      </div>
      </dd>
      <dt>8.  <span class="list-identifier"><a href="/abs/1606.02134" title="Abstract">arXiv:1606.02134</a> [<a href="/pdf/1606.02134" title="Download PDF">pdf</a>, <a href="/ps/1606.02134" title="Download PostScript">ps</a>, <a href="/format/1606.02134" title="Other formats">other</a>]</span></dt>
      <dd>
      <div class="meta">
      <div class="list-title mathjax">
      <span class="descriptor">Title:</span> Microscopic origin of self-similarity in granular blast waves
      </div>
      <div class="list-authors">
      <span class="descriptor">Authors:</span>
      <a href="/find/cond-mat/1/au:+Barbier_M/0/1/0/all/0/1">Matthieu Barbier</a>,
      <a href="/find/cond-mat/1/au:+Villamaina_D/0/1/0/all/0/1">Dario Villamaina</a>,
      <a href="/find/cond-mat/1/au:+Trizac_E/0/1/0/all/0/1">Emmanuel Trizac</a>
      </div>
      <div class="list-comments">
      <span class="descriptor">Comments:</span> 47 pages, 9 figures Supplementary Materials: 2 appendices, 3 figures
      </div>
      <div class="list-journal-ref">
      <span class="descriptor">Journal-ref:</span> Physics of Fluids 28, 083302 (2016)
      </div>
      <div class="list-subjects">
      <span class="descriptor">Subjects:</span> <span class="primary-subject">Soft Condensed Matter (cond-mat.soft)</span>

      </div>
      </div>
      </dd>
      <dt>9.  <span class="list-identifier"><a href="/abs/1604.04537" title="Abstract">arXiv:1604.04537</a> [<a href="/pdf/1604.04537" title="Download PDF">pdf</a>, <a href="/format/1604.04537" title="Other formats">other</a>]</span></dt>
      <dd>
      <div class="meta">
      <div class="list-title mathjax">
      <span class="descriptor">Title:</span> Collimation and asymmetry of the hot blast wave from the recurrent nova  V745 Scorpii
      </div>
      <div class="list-authors">
      <span class="descriptor">Authors:</span>
      <a href="/find/astro-ph/1/au:+Drake_J/0/1/0/all/0/1">Jeremy J. Drake</a>,
      <a href="/find/astro-ph/1/au:+Delgado_L/0/1/0/all/0/1">Laura Delgado</a>,
      <a href="/find/astro-ph/1/au:+Laming_J/0/1/0/all/0/1">J. Martin Laming</a>,
      <a href="/find/astro-ph/1/au:+Starrfield_S/0/1/0/all/0/1">Sumner Starrfield</a>,
      <a href="/find/astro-ph/1/au:+Kashyap_V/0/1/0/all/0/1">Vinay Kashyap</a>,
      <a href="/find/astro-ph/1/au:+Orlando_S/0/1/0/all/0/1">Salvatore Orlando</a>,
      <a href="/find/astro-ph/1/au:+Page_K/0/1/0/all/0/1">Kim L. Page</a>,
      <a href="/find/astro-ph/1/au:+Hernanz_M/0/1/0/all/0/1">M. Hernanz</a>,
      <a href="/find/astro-ph/1/au:+Ness_J/0/1/0/all/0/1">J-U. Ness</a>,
      <a href="/find/astro-ph/1/au:+Gehrz_R/0/1/0/all/0/1">R. D. Gehrz</a>,
      <a href="/find/astro-ph/1/au:+Rossum_D/0/1/0/all/0/1">Daan van Rossum</a>,
      <a href="/find/astro-ph/1/au:+Woodward_C/0/1/0/all/0/1">Charles E. Woodward</a>
      </div>
      <div class="list-comments">
      <span class="descriptor">Comments:</span> To appear in the Astrophysical Journal
      </div>
      <div class="list-subjects">
      <span class="descriptor">Subjects:</span> <span class="primary-subject">Solar and Stellar Astrophysics (astro-ph.SR)</span>; High Energy Astrophysical Phenomena (astro-ph.HE)

      </div>
      </div>
      </dd>
      <dt>10.  <span class="list-identifier"><a href="/abs/1604.04395" title="Abstract">arXiv:1604.04395</a> [<a href="/pdf/1604.04395" title="Download PDF">pdf</a>, <a href="/ps/1604.04395" title="Download PostScript">ps</a>, <a href="/format/1604.04395" title="Other formats">other</a>]</span></dt>
      <dd>
      <div class="meta">
      <div class="list-title mathjax">
      <span class="descriptor">Title:</span> Supernova-blast waves in wind-blown bubbles, turbulent, and power-law  ambient media
      </div>
      <div class="list-authors">
      <span class="descriptor">Authors:</span>
      <a href="/find/astro-ph/1/au:+Haid_S/0/1/0/all/0/1">Sebastian Haid</a>,
      <a href="/find/astro-ph/1/au:+Walch_S/0/1/0/all/0/1">Stefanie Walch</a>,
      <a href="/find/astro-ph/1/au:+Naab_T/0/1/0/all/0/1">Thorsten Naab</a>,
      <a href="/find/astro-ph/1/au:+Seifried_D/0/1/0/all/0/1">Daniel Seifried</a>,
      <a href="/find/astro-ph/1/au:+Mackey_J/0/1/0/all/0/1">Jonathan Mackey</a>,
      <a href="/find/astro-ph/1/au:+Gatto_A/0/1/0/all/0/1">Andrea Gatto</a>
      </div>
      <div class="list-subjects">
      <span class="descriptor">Subjects:</span> <span class="primary-subject">Astrophysics of Galaxies (astro-ph.GA)</span>

      </div>
      </div>
      </dd>
      <dt>11.  <span class="list-identifier"><a href="/abs/1603.06418" title="Abstract">arXiv:1603.06418</a> [<a href="/pdf/1603.06418" title="Download PDF">pdf</a>, <a href="/ps/1603.06418" title="Download PostScript">ps</a>, <a href="/format/1603.06418" title="Other formats">other</a>]</span></dt>
      <dd>
      <div class="meta">
      <div class="list-title mathjax">
      <span class="descriptor">Title:</span> Blast-wave model description of the HBT radii measured in $pp$  collisions at the LHC energies
      </div>
      <div class="list-authors">
      <span class="descriptor">Authors:</span>
      <a href="/find/nucl-th/1/au:+Florkowski_W/0/1/0/all/0/1">Wojciech Florkowski</a>
      </div>
      <div class="list-comments">
      <span class="descriptor">Comments:</span> Talk presented at the XI Workshop on Particle Correlations and Femtoscopy, dedicated to Professor Jan Pluta on the occasion of his 70th birthday
      </div>
      <div class="list-journal-ref">
      <span class="descriptor">Journal-ref:</span> Acta Phys.Polon. B47 (2016) 2241
      </div>
      <div class="list-subjects">
      <span class="descriptor">Subjects:</span> <span class="primary-subject">Nuclear Theory (nucl-th)</span>; High Energy Physics - Phenomenology (hep-ph)

      </div>
      </div>
      </dd>
      <dt>12.  <span class="list-identifier"><a href="/abs/1602.01564" title="Abstract">arXiv:1602.01564</a> [<a href="/pdf/1602.01564" title="Download PDF">pdf</a>, <a href="/ps/1602.01564" title="Download PostScript">ps</a>, <a href="/format/1602.01564" title="Other formats">other</a>]</span></dt>
      <dd>
      <div class="meta">
      <div class="list-title mathjax">
      <span class="descriptor">Title:</span> Beam energy dependence of Hanbury-Brown-Twiss radii from a blast-wave  model
      </div>
      <div class="list-authors">
      <span class="descriptor">Authors:</span>
      <a href="/find/nucl-th/1/au:+Zhang_S/0/1/0/all/0/1">S. Zhang</a>,
      <a href="/find/nucl-th/1/au:+Ma_Y/0/1/0/all/0/1">Y. G. Ma</a>,
      <a href="/find/nucl-th/1/au:+Chen_J/0/1/0/all/0/1">J. H. Chen</a>,
      <a href="/find/nucl-th/1/au:+Zhong_C/0/1/0/all/0/1">C. Zhong</a>
      </div>
      <div class="list-comments">
      <span class="descriptor">Comments:</span> 9 pages, 9 figures
      </div>
      <div class="list-subjects">
      <span class="descriptor">Subjects:</span> <span class="primary-subject">Nuclear Theory (nucl-th)</span>; High Energy Physics - Phenomenology (hep-ph); Nuclear Experiment (nucl-ex)

      </div>
      </div>
      </dd>
      <dt>13.  <span class="list-identifier"><a href="/abs/1601.05808" title="Abstract">arXiv:1601.05808</a> [<a href="/pdf/1601.05808" title="Download PDF">pdf</a>, <a href="/format/1601.05808" title="Other formats">other</a>]</span></dt>
      <dd>
      <div class="meta">
      <div class="list-title mathjax">
      <span class="descriptor">Title:</span> Transport and mixing of r-process elements in neutron star binary merger  blast waves
      </div>
      <div class="list-authors">
      <span class="descriptor">Authors:</span>
      <a href="/find/astro-ph/1/au:+Montes_G/0/1/0/all/0/1">Gabriela Montes</a>,
      <a href="/find/astro-ph/1/au:+Ramirez_Ruiz_E/0/1/0/all/0/1">Enrico Ramirez-Ruiz</a>,
      <a href="/find/astro-ph/1/au:+Naiman_J/0/1/0/all/0/1">Jill Naiman</a>,
      <a href="/find/astro-ph/1/au:+Shen_S/0/1/0/all/0/1">Sijing Shen</a>,
      <a href="/find/astro-ph/1/au:+Lee_W/0/1/0/all/0/1">William H. Lee</a>
      </div>
      <div class="list-comments">
      <span class="descriptor">Comments:</span> 8 pages, 6 figures, 2 table. Submitted to ApJ
      </div>
      <div class="list-subjects">
      <span class="descriptor">Subjects:</span> <span class="primary-subject">High Energy Astrophysical Phenomena (astro-ph.HE)</span>; Astrophysics of Galaxies (astro-ph.GA); Solar and Stellar Astrophysics (astro-ph.SR)

      </div>
      </div>
      </dd>
      <dt>14.  <span class="list-identifier"><a href="/abs/1601.03832" title="Abstract">arXiv:1601.03832</a> [<a href="/pdf/1601.03832" title="Download PDF">pdf</a>, <a href="/ps/1601.03832" title="Download PostScript">ps</a>, <a href="/format/1601.03832" title="Other formats">other</a>]</span></dt>
      <dd>
      <div class="meta">
      <div class="list-title mathjax">
      <span class="descriptor">Title:</span> Resonant Amplification of Turbulence by the Blast Wawes
      </div>
      <div class="list-authors">
      <span class="descriptor">Authors:</span>
      <a href="/find/astro-ph/1/au:+Zankovich_A/0/1/0/all/0/1">A. M. Zankovich</a>,
      <a href="/find/astro-ph/1/au:+Kovalenko_I/0/1/0/all/0/1">I. G. Kovalenko</a>
      </div>
      <div class="list-comments">
      <span class="descriptor">Comments:</span> 11 pages, 6 figures
      </div>
      <div class="list-journal-ref">
      <span class="descriptor">Journal-ref:</span> The Astrophysical Journal,2015, Volume 800, Issue 1, article id.
        28, 10 pp
      </div>
      <div class="list-subjects">
      <span class="descriptor">Subjects:</span> <span class="primary-subject">Astrophysics of Galaxies (astro-ph.GA)</span>

      </div>
      </div>
      </dd>
      <dt>15.  <span class="list-identifier"><a href="/abs/1511.02918" title="Abstract">arXiv:1511.02918</a> [<a href="/pdf/1511.02918" title="Download PDF">pdf</a>, <a href="/ps/1511.02918" title="Download PostScript">ps</a>, <a href="/format/1511.02918" title="Other formats">other</a>]</span></dt>
      <dd>
      <div class="meta">
      <div class="list-title mathjax">
      <span class="descriptor">Title:</span> Supernovae and their expanding blast waves during the early evolution of  Galactic globular clusters
      </div>
      <div class="list-authors">
      <span class="descriptor">Authors:</span>
      <a href="/find/astro-ph/1/au:+Tenorio_Tagle_G/0/1/0/all/0/1">Guillermo Tenorio-Tagle</a>,
      <a href="/find/astro-ph/1/au:+Munoz_Tunon_C/0/1/0/all/0/1">Casiana Munoz-Tunon</a>,
      <a href="/find/astro-ph/1/au:+Silich_S/0/1/0/all/0/1">Sergiy Silich</a>,
      <a href="/find/astro-ph/1/au:+Cassisi_S/0/1/0/all/0/1">Santi Cassisi</a>
      </div>
      <div class="list-comments">
      <span class="descriptor">Comments:</span> Accepted for publication in the Astrophysical Journal Letters, 10pages, 1 figure
      </div>
      <div class="list-subjects">
      <span class="descriptor">Subjects:</span> <span class="primary-subject">Astrophysics of Galaxies (astro-ph.GA)</span>

      </div>
      </div>
      </dd>
      <dt>16.  <span class="list-identifier"><a href="/abs/1510.08678" title="Abstract">arXiv:1510.08678</a> [<a href="/pdf/1510.08678" title="Download PDF">pdf</a>, <a href="/ps/1510.08678" title="Download PostScript">ps</a>, <a href="/format/1510.08678" title="Other formats">other</a>]</span></dt>
      <dd>
      <div class="meta">
      <div class="list-title mathjax">
      <span class="descriptor">Title:</span> Blast dynamics in a dissipative gas
      </div>
      <div class="list-authors">
      <span class="descriptor">Authors:</span>
      <a href="/find/cond-mat/1/au:+Barbier_M/0/1/0/all/0/1">Matthieu Barbier</a>,
      <a href="/find/cond-mat/1/au:+Villamaina_D/0/1/0/all/0/1">Dario Villamaina</a>,
      <a href="/find/cond-mat/1/au:+Trizac_E/0/1/0/all/0/1">Emmanuel Trizac</a>
      </div>
      <div class="list-comments">
      <span class="descriptor">Comments:</span> 5 pages, to appear in Physical Review Letters
      </div>
      <div class="list-journal-ref">
      <span class="descriptor">Journal-ref:</span> Phys. Rev. Lett. 115, 214301 (2015)
      </div>
      <div class="list-subjects">
      <span class="descriptor">Subjects:</span> <span class="primary-subject">Statistical Mechanics (cond-mat.stat-mech)</span>; Soft Condensed Matter (cond-mat.soft)

      </div>
      </div>
      </dd>
      <dt>17.  <span class="list-identifier"><a href="/abs/1509.05383" title="Abstract">arXiv:1509.05383</a> [<a href="/pdf/1509.05383" title="Download PDF">pdf</a>, <a href="/format/1509.05383" title="Other formats">other</a>]</span></dt>
      <dd>
      <div class="meta">
      <div class="list-title mathjax">
      <span class="descriptor">Title:</span> Blast wave fits with resonances to $p_t$ spectra from nuclear collisions  at the LHC
      </div>
      <div class="list-authors">
      <span class="descriptor">Authors:</span>
      <a href="/find/nucl-th/1/au:+Melo_I/0/1/0/all/0/1">Ivan Melo</a>,
      <a href="/find/nucl-th/1/au:+Tomasik_B/0/1/0/all/0/1">Boris Tomasik</a>
      </div>
      <div class="list-comments">
      <span class="descriptor">Comments:</span> 5 pages, Proceedings of the Strangeness in Quark Matter 2015, Dubna, July 6-11, 2015, supplementary material on the last page
      </div>
      <div class="list-subjects">
      <span class="descriptor">Subjects:</span> <span class="primary-subject">Nuclear Theory (nucl-th)</span>; Nuclear Experiment (nucl-ex)

      </div>
      </div>
      </dd>
      <dt>18.  <span class="list-identifier"><a href="/abs/1508.07830" title="Abstract">arXiv:1508.07830</a> [<a href="/pdf/1508.07830" title="Download PDF">pdf</a>, <a href="/format/1508.07830" title="Other formats">other</a>]</span></dt>
      <dd>
      <div class="meta">
      <div class="list-title mathjax">
      <span class="descriptor">Title:</span> The synchrotron-self-Compton spectrum of relativistic blast waves at  large Y
      </div>
      <div class="list-authors">
      <span class="descriptor">Authors:</span>
      <a href="/find/astro-ph/1/au:+Lemoine_M/0/1/0/all/0/1">M. Lemoine</a> (IAP)
      </div>
      <div class="list-comments">
      <span class="descriptor">Comments:</span> 13 pages, 6 figures, to appear in MNRAS
      </div>
      <div class="list-subjects">
      <span class="descriptor">Subjects:</span> <span class="primary-subject">High Energy Astrophysical Phenomena (astro-ph.HE)</span>

      </div>
      </div>
      </dd>
      <dt>19.  <span class="list-identifier"><a href="/abs/1508.05878" title="Abstract">arXiv:1508.05878</a> [<a href="/pdf/1508.05878" title="Download PDF">pdf</a>, <a href="/format/1508.05878" title="Other formats">other</a>]</span></dt>
      <dd>
      <div class="meta">
      <div class="list-title mathjax">
      <span class="descriptor">Title:</span> A viscous blast-wave model for relativistic heavy-ion collisions
      </div>
      <div class="list-authors">
      <span class="descriptor">Authors:</span>
      <a href="/find/nucl-th/1/au:+Jaiswal_A/0/1/0/all/0/1">Amaresh Jaiswal</a>,
      <a href="/find/nucl-th/1/au:+Koch_V/0/1/0/all/0/1">Volker Koch</a>
      </div>
      <div class="list-comments">
      <span class="descriptor">Comments:</span> 8 pages, 6 figures
      </div>
      <div class="list-subjects">
      <span class="descriptor">Subjects:</span> <span class="primary-subject">Nuclear Theory (nucl-th)</span>; High Energy Physics - Phenomenology (hep-ph)

      </div>
      </div>
      </dd>
      <dt>20.  <span class="list-identifier"><a href="/abs/1507.02487" title="Abstract">arXiv:1507.02487</a> [<a href="/pdf/1507.02487" title="Download PDF">pdf</a>, <a href="/ps/1507.02487" title="Download PostScript">ps</a>, <a href="/format/1507.02487" title="Other formats">other</a>]</span></dt>
      <dd>
      <div class="meta">
      <div class="list-title mathjax">
      <span class="descriptor">Title:</span> Infrared studies of Nova Scorpii 2014: an outburst in a symbiotic system  sans an accompanying blast wave
      </div>
      <div class="list-authors">
      <span class="descriptor">Authors:</span>
      <a href="/find/astro-ph/1/au:+Joshi_V/0/1/0/all/0/1">Vishal Joshi</a>,
      <a href="/find/astro-ph/1/au:+Banerjee_D/0/1/0/all/0/1">D. P. K. Banerjee</a>,
      <a href="/find/astro-ph/1/au:+Ashok_N/0/1/0/all/0/1">N M Ashok</a>,
      <a href="/find/astro-ph/1/au:+Venkataraman_V/0/1/0/all/0/1">V Venkataraman</a>,
      <a href="/find/astro-ph/1/au:+Walter_F/0/1/0/all/0/1">F.M. Walter</a>
      </div>
      <div class="list-comments">
      <span class="descriptor">Comments:</span> 9 pages, to appear in MNRAS
      </div>
      <div class="list-subjects">
      <span class="descriptor">Subjects:</span> <span class="primary-subject">Solar and Stellar Astrophysics (astro-ph.SR)</span>; High Energy Astrophysical Phenomena (astro-ph.HE)

      </div>
      </div>
      </dd>
      <dt>21.  <span class="list-identifier"><a href="/abs/1506.04893" title="Abstract">arXiv:1506.04893</a> [<a href="/pdf/1506.04893" title="Download PDF">pdf</a>, <a href="/ps/1506.04893" title="Download PostScript">ps</a>, <a href="/format/1506.04893" title="Other formats">other</a>]</span></dt>
      <dd>
      <div class="meta">
      <div class="list-title mathjax">
      <span class="descriptor">Title:</span> Diffusion of Cosmic Rays in a Multiphase Interstellar Medium Swept-Up by  a Supernova Remnant Blast Wave
      </div>
      <div class="list-authors">
      <span class="descriptor">Authors:</span>
      <a href="/find/astro-ph/1/au:+Roh_S/0/1/0/all/0/1">Soonyoung Roh</a>,
      <a href="/find/astro-ph/1/au:+Inutsuka_S/0/1/0/all/0/1">Shu-ichiro Inutsuka</a>,
      <a href="/find/astro-ph/1/au:+Inoue_T/0/1/0/all/0/1">Tsuyoshi Inoue</a>
      </div>
      <div class="list-comments">
      <span class="descriptor">Comments:</span> 20 pages, 4 tables, 10 figures
      </div>
      <div class="list-subjects">
      <span class="descriptor">Subjects:</span> <span class="primary-subject">High Energy Astrophysical Phenomena (astro-ph.HE)</span>

      </div>
      </div>
      </dd>
      <dt>22.  <span class="list-identifier"><a href="/abs/1506.04739" title="Abstract">arXiv:1506.04739</a> [<a href="/pdf/1506.04739" title="Download PDF">pdf</a>, <a href="/ps/1506.04739" title="Download PostScript">ps</a>, <a href="/format/1506.04739" title="Other formats">other</a>]</span></dt>
      <dd>
      <div class="meta">
      <div class="list-title mathjax">
      <span class="descriptor">Title:</span> Self-similar ultra-relativistic jetted blast wave
      </div>
      <div class="list-authors">
      <span class="descriptor">Authors:</span>
      <a href="/find/astro-ph/1/au:+Keshet_U/0/1/0/all/0/1">Uri Keshet</a>,
      <a href="/find/astro-ph/1/au:+Kogan_D/0/1/0/all/0/1">Dani Kogan</a>
      </div>
      <div class="list-comments">
      <span class="descriptor">Comments:</span> Revised version (discussion added) accepted by ApJ
      </div>
      <div class="list-journal-ref">
      <span class="descriptor">Journal-ref:</span> The Astrophysical Journal, Volume 815, Issue 2, article id. 100,
        15 pp. (2015)
      </div>
      <div class="list-subjects">
      <span class="descriptor">Subjects:</span> <span class="primary-subject">High Energy Astrophysical Phenomena (astro-ph.HE)</span>; Solar and Stellar Astrophysics (astro-ph.SR)

      </div>
      </div>
      </dd>
      <dt>23.  <span class="list-identifier"><a href="/abs/1506.02986" title="Abstract">arXiv:1506.02986</a> [<a href="/pdf/1506.02986" title="Download PDF">pdf</a>]</span></dt>
      <dd>
      <div class="meta">
      <div class="list-title mathjax">
      <span class="descriptor">Title:</span> Device for Underwater Laboratory Simulation of Unconfined Blast Waves
      </div>
      <div class="list-authors">
      <span class="descriptor">Authors:</span>
      <a href="/find/physics/1/au:+Courtney_E/0/1/0/all/0/1">Elijah Courtney</a>,
      <a href="/find/physics/1/au:+Courtney_A/0/1/0/all/0/1">Amy Courtney</a>,
      <a href="/find/physics/1/au:+Courtney_M/0/1/0/all/0/1">Michael Courtney</a>
      </div>
      <div class="list-subjects">
      <span class="descriptor">Subjects:</span> <span class="primary-subject">Instrumentation and Detectors (physics.ins-det)</span>

      </div>
      </div>
      </dd>
      <dt>24.  <span class="list-identifier"><a href="/abs/1505.07554" title="Abstract">arXiv:1505.07554</a> [<a href="/pdf/1505.07554" title="Download PDF">pdf</a>, <a href="/format/1505.07554" title="Other formats">other</a>]</span></dt>
      <dd>
      <div class="meta">
      <div class="list-title mathjax">
      <span class="descriptor">Title:</span> Blasting away a dwarf galaxy: The &quot;tail&quot; of ESO 324-G024
      </div>
      <div class="list-authors">
      <span class="descriptor">Authors:</span>
      <a href="/find/astro-ph/1/au:+Johnson_M/0/1/0/all/0/1">Megan C. Johnson</a>,
      <a href="/find/astro-ph/1/au:+Kamphuis_P/0/1/0/all/0/1">Peter Kamphuis</a>,
      <a href="/find/astro-ph/1/au:+Koribalski_B/0/1/0/all/0/1">Baerbel S. Koribalski</a>,
      <a href="/find/astro-ph/1/au:+Wang_J/0/1/0/all/0/1">Jing Wang</a>,
      <a href="/find/astro-ph/1/au:+Oh_S/0/1/0/all/0/1">Se-Heon Oh</a>,
      <a href="/find/astro-ph/1/au:+Hill_A/0/1/0/all/0/1">Alex S. Hill</a>,
      <a href="/find/astro-ph/1/au:+OSullivan_S/0/1/0/all/0/1">Shane O&#x27;Sullivan</a>,
      <a href="/find/astro-ph/1/au:+Haan_S/0/1/0/all/0/1">Sebastian Haan</a>,
      <a href="/find/astro-ph/1/au:+Serra_P/0/1/0/all/0/1">Paolo Serra</a>
      </div>
      <div class="list-comments">
      <span class="descriptor">Comments:</span> This paper has been accepted to MNRAS
      </div>
      <div class="list-subjects">
      <span class="descriptor">Subjects:</span> <span class="primary-subject">Astrophysics of Galaxies (astro-ph.GA)</span>

      </div>
      </div>
      </dd>
      <dt>25.  <span class="list-identifier"><a href="/abs/1505.02723" title="Abstract">arXiv:1505.02723</a> [<a href="/pdf/1505.02723" title="Download PDF">pdf</a>, <a href="/ps/1505.02723" title="Download PostScript">ps</a>, <a href="/format/1505.02723" title="Other formats">other</a>]</span></dt>
      <dd>
      <div class="meta">
      <div class="list-title mathjax">
      <span class="descriptor">Title:</span> Two step chromospheric Moreton wave excitation in a blast-wave scenario.  A case study: the December 06, 2006 event
      </div>
      <div class="list-authors">
      <span class="descriptor">Authors:</span>
      <a href="/find/astro-ph/1/au:+Krause_G/0/1/0/all/0/1">G. Krause</a>,
      <a href="/find/astro-ph/1/au:+Cecere_M/0/1/0/all/0/1">M. C&#xe9;cere</a>,
      <a href="/find/astro-ph/1/au:+Francile_C/0/1/0/all/0/1">C. Francile</a>,
      <a href="/find/astro-ph/1/au:+Costa_A/0/1/0/all/0/1">A. Costa</a>,
      <a href="/find/astro-ph/1/au:+Elaskar_S/0/1/0/all/0/1">S. Elaskar</a>,
      <a href="/find/astro-ph/1/au:+Schneiter_M/0/1/0/all/0/1">M. Schneiter</a>
      </div>
      <div class="list-comments">
      <span class="descriptor">Comments:</span> 11 figures, 9 pages, 1 table. Accepted for publication in Monthly Notices of the Royal Astronomical Society
      </div>
      <div class="list-subjects">
      <span class="descriptor">Subjects:</span> <span class="primary-subject">Solar and Stellar Astrophysics (astro-ph.SR)</span>

      </div>
      </div>
      </dd>
      </dl>
      <a href="/find/grp_math,grp_physics/1/ti:+blast/0/1/0/all/0/1?query_id=11871357850ddd36&amp;form=yes">Back to Search form</a>
      &nbsp;|&nbsp;<a href="/find/grp_math,grp_physics/1/ti:+blast/0/1/0/all/0/1?skip=25&amp;query_id=11871357850ddd36">Next 25 results</a><br/><br/><small><a id="mathjax_toggle" href="javascript:setMathjaxCookie()">Disable MathJax</a> (<a href="/help/mathjax/">What is MathJax?</a>)</small><script type="text/javascript" language="javascript">mathjaxToggle();</script>
      </div>
    </div> <!-- search-contents -->
    </div>
  </section>
  </content>
  <footer>
    <div class="columns">
      <div class="column">
        <ul class="nav-spaced">
          <li><a href="https://arxiv.org/help/contact">Contact</a></li>
          <li><a href="https://twitter.com/arxiv">Find us on Twitter</a></li>
        </ul>
      </div>
      <div class="column">
        <ul class="nav-spaced">
          <li><a href="https://blogs.cornell.edu/arxiv/">Blog - the latest news</a></li>
          <li><a href="https://confluence.cornell.edu/display/arxivpub/arXiv+Public+Wiki">Wiki - project documentation</a></li>
        </ul>
      </div>
      <div class="column">
        <ul class="nav-spaced">
          <li><a href="mailto:web-accessibility@cornell.edu">Web Accessibility Help</a></li>
          <li><a href="https://arxiv.org/help">Help with using arXiv</a></li>
        </ul>
      </div>
    </div>
  </footer>
  </body>
</html>
