<!-- contains Cornell logo and sponsor statement -->
<div class="attribution level is-marginless" role="banner">
  <div class="level-left">
    <a class="level-item" href="{{ url_for('university') }}"><img src="{{ url_for('base.static', filename='images/cornell-reduced-white-SMALL.svg') }}" alt="Cornell University" width="200" aria-label="logo" /></a>
  </div>
  <div class="level-right is-marginless"><p class="sponsors level-item is-marginless"><a href="{{ url_for('acknowledgment') }}">We gratefully acknowledge support from<br /> the Simons Foundation and member institutions.</a></p></div>
</div>
<!-- contains arXiv identity and search bar -->
<div class="identity level is-marginless">
  <div class="level-left">
    <div class="level-item">
      <a class="arxiv" href="{{ url_for('home') }}" aria-label="arxiv-logo"><img src="{{ url_for('base.static', filename='images/arxiv-logo-web.svg') }}" alt="arXiv" aria-label="logo" width="85" /></a>
    </div>
  </div>
  {{ macros.compactsearch('level-right') }}
</div> <!-- closes identity -->

<div class="container">
    <div class="user-tools is-size-7 has-text-right has-text-weight-bold" role="navigation" aria-label="User menu">
      {% if request.session and request.session.user and request.session.user.name %}Logged in as <span class="has-text-weight-bold">{{ request.session.user.name.forename }} {{ request.session.user.name.surname }} {{ request.session.user.name.suffix }}</span> | <a href="{{ url_for('account') }}">My Account</a> | <a href="{{ url_for('logout') }}">Logout</a>{% else %}<a href="{{ url_for('login') }}">Login</a>{% endif %}
    </div>
</div>
