'Created by tag_check.write_version'
#  NEVER CHECK THIS version.py file INTO GIT.
#  Generated when the package was build for distribution.
__when__ = '22/10/2020 15:07:21'
__version__ = '0.16.9rc3'
