<div class="footer" style="clear: both; text-align: center; width: 100%;">
  <table role="presentation" border="0" cellpadding="0" cellspacing="0" style="border-collapse: separate; mso-table-lspace: 0pt; mso-table-rspace: 0pt; width: 100%; border-top: 1px solid #D8D8D8;">
    <tr>
      <td class="content-block" style="font-family: Roboto, Helvetica, Arial, sans-serif; vertical-align: top; padding-bottom: 10px; padding-top: 10px; font-size: 12px; color: #5E5E5E; text-align: center;">
        <span class="apple-link" style="color: #5E5E5E; font-size: 12px; text-align: center;">arXiv, Cornell University, Ithaca NY 14853 USA<br />
        {% block addl_footer %}
          You are receiving this email because you initiated a process at arXiv.org. <br />
          If this doesn't sound right, <a href="mailto:support@arxiv.org" style="text-decoration: underline; color: #5E5E5E;"><font color="#5E5E5E">let us know</font>.</a>
        {% endblock %}
      </span>
      </td>
    </tr>
  </table>
</div>
